@@ -24,12 +24,12 @@ def choose_driver(driver_name):
         return ChromeDriverManager().install()
 
 
-def setSelenium(headless=True, proxy=False, remote_webdriver=False, driver_name="chrome"):
+def setSelenium(headless=True, rotate_useragent=False, remote_webdriver=False, driver_name="chrome", profile=False, profile_name="default"):
     """
     Set Selenium Webdriver
     args: 
         - headless: bool, True if you want to run the browser in headless mode
-        - proxy: bool, True if you want to use a proxy
+        - rotate_useragent: bool, True if you want to rotate the useragent
         - remote_webdriver: bool, True if you want to download and use the remote webdriver
         - driver_name: str, the name of the driver you want to use
 
@@ -39,8 +39,6 @@ def setSelenium(headless=True, proxy=False, remote_webdriver=False, driver_name=
 
 
     chrome_options = Options()
-    ua = UserAgent()
-    userAgent = ua.random
     load_dotenv()
 
     if headless:
@@ -55,9 +53,12 @@ def setSelenium(headless=True, proxy=False, remote_webdriver=False, driver_name=
         "profile.default_content_setting_values.notifications": 2
     })
     # evitar detecção anti-bot
-    # chrome_options.add_argument(f'user-agent={userAgent}')
 
-    # chrome_options.add_argument("user-data-dir=Pessoa_1") 
+    if rotate_useragent:
+        ua = UserAgent()
+        userAgent = ua.random
+        chrome_options.add_argument(f'user-agent={userAgent}')
+ 
     chrome_options.add_argument(f'user-agent=Mozilla/5.0 (Windows NT 10.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.77 Safari/537.36')
     chrome_options.add_argument("--disable-blink-features")
     chrome_options.add_argument('--disable-blink-features=AutomationControlled')
@@ -69,14 +70,19 @@ def setSelenium(headless=True, proxy=False, remote_webdriver=False, driver_name=
     prefs = {"profile.default_content_setting_values.notifications": 2}
     chrome_options.add_experimental_option("prefs", prefs)
 
+    if profile:
+        dir_path = os.getcwd()
+        profile = os.path.join(f"{dir_path}/{profile_name}", "profile", "wpp")
+        chrome_options.add_argument(f'user-data-dir={profile}')
+
     if remote_webdriver:
         path = choose_driver(driver_name)
 
     else:
         path = os.getenv('CHROMEDRIVER_PATH')
 
-    if proxy:
-        PROXY = init_proxy()
-        chrome_options.add_argument('--proxy-server=%s' % PROXY)
+    # if proxy:
+    #     PROXY = init_proxy()
+    #     chrome_options.add_argument('--proxy-server=%s' % PROXY)
 
     return webdriver.Chrome(chrome_options=chrome_options, executable_path=resource_path(path), service_log_path='NUL')
